<?php

require 'database_connection.php'; // ملف الاتصال بقاعدة البيانات
$user_id = '5615';


$sql = "SELECT l.*, 
            (SELECT COUNT(*) FROM stat_lin WHERE stat_lin.id_link = l.id) AS visit_count
        FROM links l 
        WHERE l.id_user = :user_id 
        ORDER BY l.id DESC";

$stmt = $pdo->prepare($sql);
$stmt->bindParam(':user_id', $user_id, PDO::PARAM_INT);
$stmt->execute();
$links = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Shorten URL</title>
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/clipboard@2.0.10/dist/clipboard.min.js"></script>

    <style>
        body {
            background-color: #f4f7fc;
            font-family: Arial, sans-serif;
        }
        .container {
            max-width: 700px;
            margin: 30px auto;
            padding: 30px;
            background-color: #fff;
            border-radius: 8px;
            box-shadow: 0 0 20px rgba(0, 0, 0, 0.1);
        }
        .link-box {
            margin-bottom: 20px;
            border: 1px solid #ddd;
            padding: 15px;
            border-radius: 8px;
            background-color: #f9f9f9;
        }
        .link-box h4 {
            margin-bottom: 10px;
            font-size: 16px;
            font-weight: bold;
            max-width: 100%;
            overflow: hidden;
            text-overflow: ellipsis;
            white-space: nowrap;
            display: block;
        }
        .link-box h4 a {
            display: inline-block;
            max-width: 100%;
            overflow: hidden;
            text-overflow: ellipsis;
            white-space: nowrap;
            color: #007bff;
            text-decoration: none;
        }
        .visit-count {
            font-size: 14px;
            color: #555;
            font-weight: bold;
            margin-top: 10px;
        }
        .copy-it {
            width: 100%;
            transition: all 0.3s ease-in-out;
        }
        .copy-it.copied {
            background-color: #28a745 !important;
            color: white !important;
        }
    </style>
</head>
<body>
 <div class="container">
        <h2 class="text-center">URL Shortener</h2>
        <form id="shorten-form" method="post">
            <div class="form-group">
                <input type="text" name="url" placeholder="Your URL Here" required="required" class="form-control form-control-lg" id="url">
            </div>
            <button class="btn btn-submit btn-primary btn-block" type="submit">Shorten</button>
        </form>

        <div id="result" style="margin-top:20px;"></div>
    </div>

    <section class="content container">
        <?php foreach ($links as $link): ?>
            <?php
            $url = $link['linkk'];
            if (!preg_match("~^(?:f|ht)tps?://~i", $url)) {
                $url = "http://" . $url;
            }
            ?>
            <div class="link-box">
                <h4 title="<?= htmlspecialchars($url); ?>">
                    <a href="<?= $url; ?>" target="_blank" rel="nofollow noopener noreferrer">
                        <?= htmlspecialchars($url); ?>
                    </a>
                </h4>
                <p class="text-muted">
                    <small>
                        <i class="fa fa-calendar"></i> <?= date('m/d/y, h:i A', strtotime($link['date'])); ?>
                    </small>
                </p>
                <div class="row">
                    <div class="col-sm-8">
                        <input type="text" class="form-control input-sm" value="https://fniyna.com/lin/<?= htmlspecialchars($link['alias']); ?>" readonly="" onfocus="this.select()">
                    </div>
                    <div class="col-sm-4">
                        <button class="btn btn-sm btn-secondary copy-it" data-clipboard-text="https://fniyna.com/lin/<?= htmlspecialchars($link['alias']); ?>" data-toggle="tooltip" title="Copy">
                            <i class="fa fa-clone"></i> Copy
                        </button>
                    </div>
                </div>
                <div class="visit-count">
                    <i class="fa fa-eye"></i> Views: <?= $link['visit_count']; ?>
                </div>
            </div>
        <?php endforeach; ?>
    </section>

    <script>
        $(document).ready(function(){
            var clipboard = new ClipboardJS('.copy-it');

            clipboard.on('success', function(e) {
                var btn = $(e.trigger);
                btn.addClass("copied").text("تم النسخ ✅");
                setTimeout(function() {
                    btn.removeClass("copied").html('<i class="fa fa-clone"></i> Copy');
                }, 2000);
            });

            clipboard.on('error', function() {
                alert('Failed to copy link!');
            });

            $("#shorten-form").submit(function(e) {
                e.preventDefault();
                $.ajax({
                    url: "shorten_proceamigoss.php",
                    type: "POST",
                    data: { url: $("#url").val() },
                    success: function(response) {
                        $("#result").html(response);
                    },
                    error: function() {
                        alert("An error occurred. Please try again.");
                    }
                });
            });
        });
    </script>

    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>
</html>
